Crate kcr_reports_x_k8s_io

Crate kcr_reports_x_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the reports.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

reports.x-k8s.io/v1beta2

  • ClusterPolicyReport
  • PolicyReport

Modules

v1beta2